@@ -13,6 +13,13 @@ SEXP rpy_list_attr(SEXP sexp);
 
 SEXP rpy_lang2str(SEXP sexp, SEXPTYPE t);
 
+SEXP externallymanaged_vector(SEXPTYPE rtype, void *array, int length);
+
+typedef struct {
+  int rfree;
+  void *array;
+} ExternallyManagedVector;
+
 #define __RPY_RSVN_SWITCH_VERSION__ 134914
 
 #endif
