@@ -191,12 +191,13 @@ import rpy2.rinterface as ri
 ri.initr()
 def f(x):
   pass
-ri.set_writeconsole(f)
-rcode = "i <- 0; "
-rcode += "while(TRUE) { "
-rcode += "i <- i+1; "
-rcode += "Sys.sleep(0.01); "
-rcode += "}"
+ri.set_writeconsole_regular(f)
+rcode = \"\"\"
+i <- 0;
+while(TRUE) {
+    i <- i+1;
+    Sys.sleep(0.01);
+}\"\"\"
 try:
   ri.baseenv['eval'](ri.parse(rcode))
 except Exception%s e:
@@ -225,27 +226,27 @@ except Exception%s e:
 
 class CallbacksTestCase(unittest.TestCase):
     def tearDown(self):
-        rinterface.set_writeconsole(rinterface.consolePrint)
+        rinterface.set_writeconsole_regular(rinterface.consolePrint)
         rinterface.set_readconsole(rinterface.consoleRead)
         rinterface.set_readconsole(rinterface.consoleFlush)
         rinterface.set_choosefile(rinterface.chooseFile)
         sys.last_value = None
 
-    def testSetWriteConsole(self):
+    def testSetWriteConsoleRegular(self):
         buf = []
         def f(x):
             buf.append(x)
 
-        rinterface.set_writeconsole(f)
-        self.assertEqual(rinterface.get_writeconsole(), f)
+        rinterface.set_writeconsole_regular(f)
+        self.assertEqual(rinterface.get_writeconsole_regular(), f)
         code = rinterface.SexpVector(["3", ], rinterface.STRSXP)
         rinterface.baseenv["print"](code)
         self.assertEqual('[1] "3"\n', str.join('', buf))
 
-    def testWriteConsoleWithError(self):
+    def testWriteConsoleRegularWithError(self):
         def f(x):
             raise CustomException("Doesn't work.")
-        rinterface.set_writeconsole(f)
+        rinterface.set_writeconsole_regular(f)
 
         tmp_file = tempfile.NamedTemporaryFile()
         stderr = sys.stderr
@@ -264,6 +265,19 @@ class CallbacksTestCase(unittest.TestCase):
         #self.assertTrue(errorstring.startswith('Traceback'))
         #tmp_file.close()
 
+    def testSetResetConsole(self):
+        reset = [0]
+        def f():
+            reset[0] += 1
+
+        rinterface.set_resetconsole(f)
+        self.assertEqual(rinterface.get_resetconsole(), f)
+        try:
+            rinterface.baseenv['eval'](rinterface.parse('1+"a"'))
+        except rinterface.RRuntimeError:
+            pass
+        self.assertEqual(1, reset[0])
+
     @onlyAQUAorWindows
     def testSetFlushConsole(self):
         flush = {'count': 0}
@@ -274,7 +288,7 @@ class CallbacksTestCase(unittest.TestCase):
         self.assertEqual(rinterface.get_flushconsole(), f)
         rinterface.baseenv.get("flush.console")()
         self.assertEqual(1, flush['count'])
-        rinterface.set_writeconsole(rinterface.consoleFlush)
+        rinterface.set_writeconsole_regular(rinterface.consoleFlush)
 
     @onlyAQUAorWindows
     def testFlushConsoleWithError(self):
@@ -355,28 +369,13 @@ class CallbacksTestCase(unittest.TestCase):
     def testChooseFileWithError(self):
         def noconsole(x):
             pass
-        rinterface.set_writeconsole(noconsole) # reverted by the tearDown method
+        rinterface.set_writeconsole_regular(noconsole) # reverted by the tearDown method
         def f(prompt):
             raise Exception("Doesn't work.")
         rinterface.set_choosefile(f)
-
-        tmp_file = tempfile.NamedTemporaryFile()
-        stderr = sys.stderr
-        sys.stderr = tmp_file
-        try:
-            res = rinterface.baseenv["file.choose"]()
-        except rinterface.RRuntimeError:
-            pass
-        except Exception as e:
-            sys.stderr = stderr
-            raise e
-        sys.stderr = stderr
-        tmp_file.flush()
-        tmp_file.seek(0)
+        self.assertRaises(rinterface.RRuntimeError,
+                          rinterface.baseenv["file.choose"])
         self.assertEqual("Doesn't work.", str(sys.last_value))
-        #errorstring = ''.join(tmp_file.readlines())
-        #self.assertTrue(errorstring.startswith('Traceback'))
-        #tmp_file.close()
 
     def testSetShowFiles(self):
         sf = []
